# MyUtils 

[![Coverage Status](https://img.shields.io/badge/%20Python%20Versions-%3E%3D3.12-informational)](https://pypi.org/project/orch-serv/)
[![Coverage Status](https://coveralls.io/repos/github/Shchusia/MyUtils/badge.svg?branch=master)](https://coveralls.io/github/Shchusia/MyUtils?branch=master)

[![Coverage Status](https://img.shields.io/badge/Version-0.1.1-informational)](https://pypi.org/project/orch-serv/)
[![Coverage Status](https://img.shields.io/badge/Docs-passed-green)](https://shchusia.github.io/MyUtils/)



> Library with help functions and classes for work

### Installation

```bash
pip install my_utilities
```


What contains:
+ helper functions for working with [iterables](https://github.com/Shchusia/MyUtils/tree/master/my_utilities/iterables/README.MD) objects 
+ helper functions for working with [probability](https://github.com/Shchusia/MyUtils/tree/master/my_utilities/probability/README.MD)
+ helper functions for pretty [view](https://github.com/Shchusia/MyUtils/tree/master/my_utilities/view/README.MD)
+ [mixins](https://github.com/Shchusia/MyUtils/tree/master/my_utilities/mixins/README.MD)
